@@ -11,7 +11,7 @@ use crate::mysql::Keyword::{
 pub enum Token {
     /// An end-of-file marker, not a real token
     EOF,
-    /// An unsigned numeric literal
+    /// A signed numeric literal
     Number(String, bool),
     /// TABLE instruction
     Word(Word),
@@ -320,39 +320,7 @@ impl<'a> Tokenizer<'a> {
                     Ok(Some(Token::SingleQuotedString(s)))
                 }
                 // numbers and period
-                '0'..='9' | '.' => {
-                    let mut s = peeking_take_while(chars, |ch| matches!(ch, '0'..='9'));
-
-                    // match binary literal that starts with 0x
-                    if s == "0" && chars.peek() == Some(&'x') {
-                        chars.next();
-                        let s2 = peeking_take_while(
-                            chars,
-                            |ch| matches!(ch, '0'..='9' | 'A'..='F' | 'a'..='f'),
-                        );
-                        return Ok(Some(Token::HexStringLiteral(s2)));
-                    }
-
-                    // match one period
-                    if let Some('.') = chars.peek() {
-                        s.push('.');
-                        chars.next();
-                    }
-                    s += &peeking_take_while(chars, |ch| matches!(ch, '0'..='9'));
-
-                    // No number -> Token::Period
-                    if s == "." {
-                        return Ok(Some(Token::Period));
-                    }
-
-                    let long = if chars.peek() == Some(&'L') {
-                        chars.next();
-                        true
-                    } else {
-                        false
-                    };
-                    Ok(Some(Token::Number(s, long)))
-                }
+                '0'..='9' | '.' => self.tokenize_number_literal(chars, None),
                 // punctuation
                 '(' => self.consume_and_return(chars, Token::LParen),
                 ')' => self.consume_and_return(chars, Token::RParen),
@@ -369,6 +337,8 @@ impl<'a> Tokenizer<'a> {
                                 comment,
                             })))
                         }
+                        // This is still not exhaustive as "SELECT - 1 as test" in postgres would return a numeric -1.
+                        Some('0'..='9') => self.tokenize_number_literal(chars, Some('-')),
                         // a regular '-' operator
                         _ => Ok(Some(Token::Minus)),
                     }
@@ -384,7 +354,15 @@ impl<'a> Tokenizer<'a> {
                         _ => Ok(Some(Token::Div)),
                     }
                 }
-                '+' => self.consume_and_return(chars, Token::Plus),
+                '+' => {
+                    chars.next(); // consume the '+'
+                    match chars.peek() {
+                        // This is still not exhaustive as "SELECT + 1 as test" in postgres would return a numeric 1.
+                        Some('0'..='9') => self.tokenize_number_literal(chars, Some('+')),
+                        // a regular '-' operator
+                        _ => Ok(Some(Token::Plus)),
+                    }
+                }
                 '*' => self.consume_and_return(chars, Token::Mul),
                 '%' => self.consume_and_return(chars, Token::Mod),
                 '=' => {
@@ -503,29 +481,24 @@ impl<'a> Tokenizer<'a> {
         chars: &mut Peekable<Chars<'_>>,
     ) -> Result<String, TokenizerError> {
         let mut s = String::new();
-        chars.next(); // consume the opening quote
+        let quote_char = chars.next().expect("opening quote character"); // consume the opening quote
 
+        // MySQL escape sequances - https://dev.mysql.com/doc/refman/5.6/en/string-literals.html#character-escape-sequences
         // slash escaping is specific to some dialect
-        let mut is_escaped = false;
         while let Some(&ch) = chars.peek() {
             match ch {
-                '\'' | '`' => {
+                '\\' => {
+                    // next char is escaped
                     chars.next(); // consume
-
-                    if let Some(next_char) = chars.peek() {
-                        if ch != '`' && *next_char != ')' && *next_char != ',' {
-                            is_escaped = true;
-                            s.push(ch);
-                        } else {
-                            return Ok(s);
-                        }
-                    }
-
-                    if !is_escaped {
-                        chars.next(); // consume
-                        s.push(ch);
+                    s.push(ch);
+                    if let Some(next_char) = chars.next() {
+                        s.push(next_char);
                     }
                 }
+                b if b == quote_char => {
+                    chars.next(); // consume
+                    return Ok(s);
+                }
                 _ => {
                     chars.next(); // consume
                     s.push(ch);
@@ -536,6 +509,51 @@ impl<'a> Tokenizer<'a> {
         self.tokenizer_error("Unterminated string literal")
     }
 
+    // Read a signed number literal
+    fn tokenize_number_literal(
+        &self,
+        chars: &mut Peekable<Chars<'_>>,
+        sign: Option<char>
+    ) -> Result<Option<Token>, TokenizerError> {
+        let mut s = match sign {
+            Some(ch) if ch == '+' || ch == '-' => {
+                String::from(ch) + &peeking_take_while(chars, |ch| matches!(ch, '0'..='9'))
+            }
+            Some(_) => panic!("invalid sign"),
+            None => peeking_take_while(chars, |ch| matches!(ch, '0'..='9'))
+        };
+
+        // match binary literal that starts with 0x
+        if s == "0" && chars.peek() == Some(&'x') {
+            chars.next();
+            let s2 = peeking_take_while(
+                chars,
+                |ch| matches!(ch, '0'..='9' | 'A'..='F' | 'a'..='f'),
+            );
+            return Ok(Some(Token::HexStringLiteral(s2)));
+        }
+
+        // match one period
+        if let Some('.') = chars.peek() {
+            s.push('.');
+            chars.next();
+        }
+        s += &peeking_take_while(chars, |ch| matches!(ch, '0'..='9'));
+
+        // No number -> Token::Period
+        if s == "." {
+            return Ok(Some(Token::Period));
+        }
+
+        let long = if chars.peek() == Some(&'L') {
+            chars.next();
+            true
+        } else {
+            false
+        };
+        Ok(Some(Token::Number(s, long)))
+    }
+
     fn tokenize_multiline_comment(
         &self,
         chars: &mut Peekable<Chars<'_>>,
@@ -727,34 +745,34 @@ pub fn trim_pre_whitespaces(tokens: Vec<Token>) -> Vec<Token> {
 mod tests {
     use crate::mysql::{
         get_column_names_from_insert_into_query, get_column_values_from_insert_into_query,
-        get_tokens_from_query_str, match_keyword_at_position, trim_pre_whitespaces, Token,
-        Tokenizer, Whitespace, get_single_quoted_string_value_at_position,
+        get_single_quoted_string_value_at_position, get_tokens_from_query_str,
+        match_keyword_at_position, trim_pre_whitespaces, Token, Tokenizer, Whitespace,
     };
 
     #[test]
     fn test_tokenize_single_quoted_string() {
         // single quoted strings must end with a commar or a closing parenthese.
-        let q = "'People\'sRepublic',";
+        let q = "'People\\'sRepublic',";
         let tokenizer = Tokenizer::new(q);
         let mut chars = q.chars().peekable();
         let single_quoted_string = tokenizer.tokenize_single_quoted_string(&mut chars).unwrap();
-        assert_eq!(single_quoted_string, "People\'sRepublic".to_string());
+        assert_eq!(single_quoted_string, "People\\'sRepublic".to_string());
 
-        let q = "'People\'sRepublic')";
+        let q = "'People\\'sRepublic')";
         let tokenizer = Tokenizer::new(q);
         let mut chars = q.chars().peekable();
         let single_quoted_string = tokenizer.tokenize_single_quoted_string(&mut chars).unwrap();
-        assert_eq!(single_quoted_string, "People\'sRepublic".to_string());
+        assert_eq!(single_quoted_string, "People\\'sRepublic".to_string());
     }
 
     #[test]
     fn tokenizer_for_create_table_query() {
         let q = r"
 CREATE TABLE `customer_store` (
-  `store_id` int NOT NULL,
+  `store_id` int NOT NULL COMMENT 'Field sample comment',
   `customer_id` int NOT NULL,
   KEY `customer_store_store_id_customer_id_index` (`store_id`,`customer_id`)
-) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;";
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci COMMENT='Table sample comment';";
 
         let mut tokenizer = Tokenizer::new(q);
         let tokens_result = tokenizer.tokenize();
@@ -779,6 +797,10 @@ CREATE TABLE `customer_store` (
             Token::make_word("NOT", None),
             Token::Whitespace(Whitespace::Space),
             Token::make_keyword("NULL"),
+            Token::Whitespace(Whitespace::Space),
+            Token::make_keyword("COMMENT"),
+            Token::Whitespace(Whitespace::Space),
+            Token::SingleQuotedString("Field sample comment".to_string()),
             Token::Comma,
             Token::Whitespace(Whitespace::Newline),
             Token::Whitespace(Whitespace::Space),
@@ -819,6 +841,10 @@ CREATE TABLE `customer_store` (
             Token::make_keyword("COLLATE"),
             Token::Eq,
             Token::make_keyword("utf8mb4_unicode_ci"),
+            Token::Whitespace(Whitespace::Space),
+            Token::make_keyword("COMMENT"),
+            Token::Eq,
+            Token::SingleQuotedString("Table sample comment".to_string()),
             Token::SemiColon,
         ];
 
@@ -867,7 +893,7 @@ CREATE TABLE `customer_store` (
 
     #[test]
     fn tokenize_insert_into_with_special_chars() {
-        let q = "INSERT INTO `country` VALUES ('CHN','China','Asia','Eastern Asia',9572900.00,-1523,1277558000,71.4,982268.00,917719.00,'Zhongquo','People\'sRepublic','Jiang Zemin',1891,'CN');";
+        let q = "INSERT INTO `country` VALUES ('CHN','China','Asia','Eastern Asia',9572900.00,-1523,+1277558000,71.4,982268.00,917719.00,'Zhongquo','People\\'sRepublic','Jiang Zemin',1891,'CN');";
 
         let mut tokenizer = Tokenizer::new(q);
         let tokens_result = tokenizer.tokenize();
@@ -893,10 +919,9 @@ CREATE TABLE `customer_store` (
             Token::Comma,
             Token::Number("9572900.00".to_string(), false),
             Token::Comma,
-            Token::Minus,
-            Token::Number("1523".to_string(), false),
+            Token::Number("-1523".to_string(), false),
             Token::Comma,
-            Token::Number("1277558000".to_string(), false),
+            Token::Number("+1277558000".to_string(), false),
             Token::Comma,
             Token::Number("71.4".to_string(), false),
             Token::Comma,
@@ -906,7 +931,7 @@ CREATE TABLE `customer_store` (
             Token::Comma,
             Token::SingleQuotedString("Zhongquo".to_string()),
             Token::Comma,
-            Token::SingleQuotedString("People\'sRepublic".to_string()),
+            Token::SingleQuotedString("People\\'sRepublic".to_string()),
             Token::Comma,
             Token::SingleQuotedString("Jiang Zemin".to_string()),
             Token::Comma,
@@ -950,7 +975,7 @@ VALUES (1,'Stanford','Stiedemann','alaina.moore@example.net','EUR',1,'2022-04-13
 
     #[test]
     fn test_get_column_values_from_insert_into_query() {
-        let q = "INSERT INTO `customers` (`id`, `first_name`, `last_name`, `email`, `currency`, `accepts_marketing`, `birthdate`, `created_at`, `updated_at`) VALUES (1,'Stanford','People\'sRepublic','alaina.moore@example.net','EUR',1,NULL,'2022-04-13 20:29:23','2022-04-13 20:29:23');";
+        let q = "INSERT INTO `customers` (`id`, `first_name`, `last_name`, `email`, `currency`, `accepts_marketing`, `birthdate`, `created_at`, `updated_at`) VALUES (1,'Stanford','People\\'sRepublic','alaina.moore@example.net','EUR',1,NULL,'2022-04-13 20:29:23','2022-04-13 20:29:23');";
 
         let mut tokenizer = Tokenizer::new(q);
         let tokens_result = tokenizer.tokenize();
@@ -965,7 +990,7 @@ VALUES (1,'Stanford','Stiedemann','alaina.moore@example.net','EUR',1,'2022-04-13
             vec![
                 &Token::Number("1".to_string(), false),
                 &Token::SingleQuotedString("Stanford".to_string()),
-                &Token::SingleQuotedString("People\'sRepublic".to_string()),
+                &Token::SingleQuotedString("People\\'sRepublic".to_string()),
                 &Token::SingleQuotedString("alaina.moore@example.net".to_string()),
                 &Token::SingleQuotedString("EUR".to_string()),
                 &Token::Number("1".to_string(), false),
@@ -1030,7 +1055,31 @@ VALUES ('Romaric', true);
         assert_eq!(tokens_result.is_ok(), true);
 
         let tokens = trim_pre_whitespaces(tokens_result.unwrap());
-        assert_eq!("customers", get_single_quoted_string_value_at_position(&tokens, 4).unwrap());
+        assert_eq!(
+            "customers",
+            get_single_quoted_string_value_at_position(&tokens, 4).unwrap()
+        );
         assert!(get_single_quoted_string_value_at_position(&tokens, 0).is_none());
     }
+
+    #[test]
+    fn test_insert_into_with_numbers() {
+        let q = "INSERT INTO test (postive_number, negative_number, long_number) VALUES (+5.75, -10.20, 20L);";
+
+        let mut tokenizer = Tokenizer::new(q);
+        let tokens_result = tokenizer.tokenize();
+        assert_eq!(tokens_result.is_ok(), true);
+
+        let tokens = trim_pre_whitespaces(tokens_result.unwrap());
+        let column_values = get_column_values_from_insert_into_query(&tokens);
+
+        assert_eq!(
+            column_values,
+            vec![
+                &Token::Number("+5.75".to_string(), false),
+                &Token::Number("-10.20".to_string(), false),
+                &Token::Number("20".to_string(), true),
+            ]
+        );
+    }
 }
