@@ -11,7 +11,7 @@ use crate::postgres::Keyword::{
 pub enum Token {
     /// An end-of-file marker, not a real token
     EOF,
-    /// An unsigned numeric literal
+    /// An unsigned numeric literal (numeric string, is_long)
     Number(String, bool),
     /// TABLE instruction
     Word(Word),
@@ -330,39 +330,7 @@ impl<'a> Tokenizer<'a> {
                     Ok(Some(Token::SingleQuotedString(s)))
                 }
                 // numbers and period
-                '0'..='9' | '.' => {
-                    let mut s = peeking_take_while(chars, |ch| matches!(ch, '0'..='9'));
-
-                    // match binary literal that starts with 0x
-                    if s == "0" && chars.peek() == Some(&'x') {
-                        chars.next();
-                        let s2 = peeking_take_while(
-                            chars,
-                            |ch| matches!(ch, '0'..='9' | 'A'..='F' | 'a'..='f'),
-                        );
-                        return Ok(Some(Token::HexStringLiteral(s2)));
-                    }
-
-                    // match one period
-                    if let Some('.') = chars.peek() {
-                        s.push('.');
-                        chars.next();
-                    }
-                    s += &peeking_take_while(chars, |ch| matches!(ch, '0'..='9'));
-
-                    // No number -> Token::Period
-                    if s == "." {
-                        return Ok(Some(Token::Period));
-                    }
-
-                    let long = if chars.peek() == Some(&'L') {
-                        chars.next();
-                        true
-                    } else {
-                        false
-                    };
-                    Ok(Some(Token::Number(s, long)))
-                }
+                '0'..='9' | '.' => self.tokenize_number_literal(chars, None),
                 // punctuation
                 '(' => self.consume_and_return(chars, Token::LParen),
                 ')' => self.consume_and_return(chars, Token::RParen),
@@ -379,6 +347,8 @@ impl<'a> Tokenizer<'a> {
                                 comment,
                             })))
                         }
+                        // This is still not exhaustive as "SELECT - 1 as test" in postgres would return a numeric -1.
+                        Some('0'..='9') => self.tokenize_number_literal(chars, Some('-')),
                         // a regular '-' operator
                         _ => Ok(Some(Token::Minus)),
                     }
@@ -394,7 +364,15 @@ impl<'a> Tokenizer<'a> {
                         _ => Ok(Some(Token::Div)),
                     }
                 }
-                '+' => self.consume_and_return(chars, Token::Plus),
+                '+' => {
+                    chars.next(); // consume the '+'
+                    match chars.peek() {
+                        // This is still not exhaustive as "SELECT + 1 as test" in postgres would return a numeric 1.
+                        Some('0'..='9') => self.tokenize_number_literal(chars, Some('+')),
+                        // a regular '-' operator
+                        _ => Ok(Some(Token::Plus)),
+                    }
+                }
                 '*' => self.consume_and_return(chars, Token::Mul),
                 '%' => self.consume_and_return(chars, Token::Mod),
                 '|' => {
@@ -530,20 +508,22 @@ impl<'a> Tokenizer<'a> {
         let mut s = String::new();
         chars.next(); // consume the opening quote
 
-        // slash escaping is specific to some dialect
-        let mut is_escaped = false;
+        // PostgreSQL - https://www.postgresql.org/docs/current/sql-syntax-lexical.html#SQL-BACKSLASH-TABLE
+        // in postgres quotes are escaped with ''
         while let Some(&ch) = chars.peek() {
             match ch {
                 '\'' => {
-                    chars.next(); // consume
-                    if is_escaped {
-                        s.push(ch);
-                        is_escaped = false;
-                    } else if chars.peek().map(|c| *c == '\'').unwrap_or(false) {
-                        s.push(ch);
-                        chars.next();
-                    } else {
-                        return Ok(s);
+                    chars.next(); // consume '
+                    match chars.peek() {
+                        // escaped
+                        Some('\'') => {
+                            chars.next(); // consume second '
+                            s.push('\'');
+                            s.push('\'');
+                        }
+                        _ => {
+                            return Ok(s);
+                        }
                     }
                 }
                 _ => {
@@ -556,6 +536,51 @@ impl<'a> Tokenizer<'a> {
         self.tokenizer_error("Unterminated string literal")
     }
 
+    // Read a signed number literal
+    fn tokenize_number_literal(
+        &self,
+        chars: &mut Peekable<Chars<'_>>,
+        sign: Option<char>
+    ) -> Result<Option<Token>, TokenizerError> {
+        let mut s = match sign {
+            Some(ch) if ch == '+' || ch == '-' => {
+                String::from(ch) + &peeking_take_while(chars, |ch| matches!(ch, '0'..='9'))
+            }
+            Some(_) => panic!("invalid sign"),
+            None => peeking_take_while(chars, |ch| matches!(ch, '0'..='9'))
+        };
+
+        // match binary literal that starts with 0x
+        if s == "0" && chars.peek() == Some(&'x') {
+            chars.next();
+            let s2 = peeking_take_while(
+                chars,
+                |ch| matches!(ch, '0'..='9' | 'A'..='F' | 'a'..='f'),
+            );
+            return Ok(Some(Token::HexStringLiteral(s2)));
+        }
+
+        // match one period
+        if let Some('.') = chars.peek() {
+            s.push('.');
+            chars.next();
+        }
+        s += &peeking_take_while(chars, |ch| matches!(ch, '0'..='9'));
+
+        // No number -> Token::Period
+        if s == "." {
+            return Ok(Some(Token::Period));
+        }
+
+        let long = if chars.peek() == Some(&'L') {
+            chars.next();
+            true
+        } else {
+            false
+        };
+        Ok(Some(Token::Number(s, long)))
+    }
+
     fn tokenize_multiline_comment(
         &self,
         chars: &mut Peekable<Chars<'_>>,
@@ -741,9 +766,13 @@ pub fn get_column_values_str_from_insert_into_query(tokens: &Vec<Token>) -> Vec<
         .filter_map(|x| match *x {
             Token::Word(word) => Some(word.value.clone()),
             Token::SingleQuotedString(word) => Some(word.clone()),
-            Token::Number(value, is_negative) => Some(match is_negative {
+            Token::Number(value, is_long) => Some(match is_long {
                 false => value.clone(),
-                true => format!("-{}", value),
+                true => {
+                    let mut long_value = value.to_owned();
+                    long_value.push('L');
+                    long_value
+                },
             }),
             _ => None,
         })
@@ -978,4 +1007,25 @@ VALUES ('Romaric', true);
             ]
         );
     }
+
+    #[test]
+    fn test_insert_into_with_numbers() {
+        let q = "INSERT INTO public.test (postive_number, negative_number, long_number) VALUES (+5.75, -10.20, 20L);";
+
+        let mut tokenizer = Tokenizer::new(q);
+        let tokens_result = tokenizer.tokenize();
+        assert_eq!(tokens_result.is_ok(), true);
+
+        let tokens = trim_pre_whitespaces(tokens_result.unwrap());
+        let column_values = get_column_values_from_insert_into_query(&tokens);
+
+        assert_eq!(
+            column_values,
+            vec![
+                &Token::Number("+5.75".to_string(), false),
+                &Token::Number("-10.20".to_string(), false),
+                &Token::Number("20".to_string(), true),
+            ]
+        );
+    }
 }
