@@ -159,31 +159,12 @@ fn list_statements(query: &str) -> Vec<Statement> {
     let mut sql_statements = vec![];
     let mut stack = vec![];
 
-    let is_next_char_comment = if query.find("--").is_some() {
-        // it means there is comments in this query string
-        let x: Box<dyn Fn(usize) -> bool> = if query.len() == query.chars().count() {
-            Box::new(|next_idx: usize| {
-                query.len() > next_idx && &query[next_idx..next_idx + 1] == "-"
-            })
-        } else {
-            // very low performance ... chars().nth(idx) is O(n)
-            Box::new(|next_idx: usize| {
-                query.len() > next_idx && query.chars().nth(next_idx) == Some('-')
-            })
-        };
-
-        x
-    // check if query contains multiple bytes utf-8 chars
-    } else {
-        let x: Box<dyn Fn(usize) -> bool> = Box::new(|_: usize| false);
-        x
-    };
-
     let mut is_statement_complete = true;
     let mut is_comment_line = false;
     let mut is_partial_comment_line = false;
     let mut start_index = 0usize;
     let mut previous_chars_are_whitespaces = true;
+    let query_bytes = query.as_bytes();
     for (idx, byte_char) in query.bytes().enumerate() {
         let next_idx = idx + 1;
 
@@ -205,7 +186,9 @@ fn list_statements(query: &str) -> Vec<Statement> {
             b'\'' if !is_comment_line && !is_partial_comment_line => {
                 if stack.get(0) == Some(&b'\'') {
                     if (query.len() > next_idx) && &query[next_idx..next_idx] == "'" {
-                        // do nothing because the ' char is escaped
+                        // do nothing because the ' char is escaped via a double ''
+                    } else if idx > 0 && query.is_char_boundary(idx-1) && &query[idx-1..idx] == "\\" {
+                        // do nothing because the ' char is escaped via a backslash
                     } else {
                         let _ = stack.remove(0);
                     }
@@ -239,14 +222,17 @@ fn list_statements(query: &str) -> Vec<Statement> {
             b'-' if !is_comment_line
                 && previous_chars_are_whitespaces
                 && is_statement_complete
-                && is_next_char_comment(next_idx) =>
+                && next_idx < query_bytes.len() && query_bytes[next_idx] == b'-' =>
             {
                 // comment
                 is_comment_line = true;
                 previous_chars_are_whitespaces = false;
             }
             // use grapheme instead of code points or bytes?
-            b'-' if !is_statement_complete && is_next_char_comment(next_idx) => {
+            b'-' if !is_statement_complete 
+                && next_idx < query_bytes.len() && query_bytes[next_idx] == b'-'
+                && stack.get(0) != Some(&b'\'') =>
+            {
                 // comment
                 is_partial_comment_line = true;
                 previous_chars_are_whitespaces = false;
@@ -401,6 +387,23 @@ Etiam augue augue, bibendum et molestie non, finibus non nulla. Etiam quis rhonc
             }
         }
 
+        let s = list_statements(
+            "INSERT INTO public.toto (first_name, last_name) VALUES ('jo--hn', 'd;--oe');",
+        );
+        assert_eq!(s.len(), 1);
+
+        match s.get(0).unwrap() {
+            Statement::NewLine => {
+                assert!(false);
+            }
+            Statement::CommentLine(_) => {
+                assert!(false);
+            }
+            Statement::Query(s) => {
+                assert!(s.valid);
+            }
+        }
+
         let s = list_statements(
             "INSERT INTO public.toto (first_name, last_name) VALUES ('john', 'doe'",
         );
@@ -505,6 +508,23 @@ Etiam augue augue, bibendum et molestie non, finibus non nulla. Etiam quis rhonc
             }
         }
 
+        let s = list_statements(
+            "INSERT INTO public.toto (first_name, last_name) VALUES ('jo\\'hn', 'doe');",
+        );
+        assert_eq!(s.len(), 1);
+
+        match s.get(0).unwrap() {
+            Statement::NewLine => {
+                assert!(false);
+            }
+            Statement::CommentLine(_) => {
+                assert!(false);
+            }
+            Statement::Query(s) => {
+                assert!(s.valid);
+            }
+        }
+
         let s = list_statements(
             "INSERT INTO public.toto (first_name, last_name, description) VALUES\
                 ('jo''hn', 'doe', 'wadawdw'';awdawd; awd;awdawdaw rm -rf ;dawd;');",
