@@ -1,6 +1,6 @@
 use std::io::Error;
 
-use crate::config::{DatabaseSubsetConfig, SkipConfig};
+use crate::config::{DatabaseSubsetConfig, OnlyTablesConfig, SkipConfig};
 use crate::connector::Connector;
 use crate::transformer::Transformer;
 use crate::types::{OriginalQuery, Query};
@@ -24,4 +24,5 @@ pub struct SourceOptions<'a> {
     pub transformers: &'a Vec<Box<dyn Transformer>>,
     pub skip_config: &'a Vec<SkipConfig>,
     pub database_subset: &'a Option<DatabaseSubsetConfig>,
+    pub only_tables: &'a Vec<OnlyTablesConfig>,
 }
