@@ -81,7 +81,7 @@ impl<'a> Source for Mysql<'a> {
             "--complete-insert",   // have column names in INSERT INTO rows
             "--single-transaction", // https://dev.mysql.com/doc/refman/8.0/en/mysqldump.html#option_mysqldump_single-transaction
             "--quick", // reads out large tables in a way that doesn't require having enough RAM to fit the full table in memory
-            "--databases",
+            "--hex-blob",
             self.database,
         ];
 
@@ -95,6 +95,14 @@ impl<'a> Source for Mysql<'a> {
 
         dump_args.append(&mut ignore_tables_args);
 
+        let mut only_tables_args: Vec<&str> = options
+            .only_tables
+            .iter()
+            .map(|cfg| String::as_str(&cfg.table))
+            .collect();
+
+        dump_args.append(&mut only_tables_args);
+
         let mut process = Command::new("mysqldump")
             .args(dump_args)
             .stdout(Stdio::piped())
@@ -194,7 +202,8 @@ fn transform_columns(
     // R Paren      -> position X?
     let column_names = get_column_names_from_insert_into_query(&tokens);
     let column_values = get_column_values_from_insert_into_query(&tokens);
-
+    assert_eq!(column_names.len(), column_values.len(), "Column names do not match values: got {} names and {} values", column_names.len(), column_values.len());
+    
     let mut original_columns = vec![];
     let mut columns = vec![];
 
@@ -370,6 +379,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
 
         assert!(p.read(source_options, |_original_query, _query| {}).is_ok());
@@ -381,6 +391,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
         assert!(p
             .read(source_options, |_original_query, _query| {})
@@ -396,6 +407,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
         let _ = p.read(source_options, |original_query, query| {
             assert!(original_query.data().len() > 0);
@@ -481,4 +493,25 @@ CONSTRAINT `city_ibfk_1` FOREIGN KEY (`CountryCode`) REFERENCES `country` (`Code
         };
         assert_eq!(get_row_type(&tokens), expected_row_type);
     }
+
+    #[test]
+    fn test_create_table_without_comma_at_the_end_of_the_last_property() {
+        let q = "CREATE TABLE `test` (
+ `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
+ `withDefault` tinyint(1) NOT NULL DEFAULT '0',
+) ENGINE=InnoDB DEFAULT CHARSET=latin1;";
+
+        let mut tokenizer = Tokenizer::new(q);
+        let tokens = tokenizer.tokenize().unwrap();
+        assert_eq!(is_create_table_statement(&tokens), true);
+
+        let q = "CREATE TABLE `test` (
+ `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
+ `withDefault` tinyint(1) NOT NULL DEFAULT '0'
+) ENGINE=InnoDB DEFAULT CHARSET=latin1;";
+
+        let mut tokenizer = Tokenizer::new(q);
+        let tokens = tokenizer.tokenize().unwrap();
+        assert_eq!(is_create_table_statement(&tokens), true);
+    }
 }
