@@ -83,20 +83,35 @@ impl<'a> Source for Postgres<'a> {
     ) -> Result<(), Error> {
         let s_port = self.port.to_string();
 
+        let mut dump_args = vec![
+            "--column-inserts", // dump data as INSERT commands with column names
+            "--no-owner",       // skip restoration of object ownership
+            "-h",
+            self.host,
+            "-p",
+            s_port.as_str(),
+            "-U",
+            self.username,
+        ];
+
+        let only_tables_args: Vec<String> = options
+            .only_tables
+            .iter()
+            .map(|cfg| format!("--table={}.{}", cfg.database, cfg.table))
+            .collect();
+        let mut only_tables_args: Vec<&str> = only_tables_args
+            .iter()
+            .map(String::as_str)
+            .collect();
+
+        dump_args.append(&mut only_tables_args);
+
+        dump_args.push(self.database);
+
         // TODO: as for mysql we can exclude tables directly here so we can remove the skip_tables_map checks
         let mut process = Command::new("pg_dump")
             .env("PGPASSWORD", self.password)
-            .args([
-                "--column-inserts", // dump data as INSERT commands with column names
-                "--no-owner",       // skip restoration of object ownership
-                "-h",
-                self.host,
-                "-p",
-                s_port.as_str(),
-                "-U",
-                self.username,
-                self.database,
-            ])
+            .args(dump_args)
             .stdout(Stdio::piped())
             .stderr(Stdio::piped())
             .spawn()?;
@@ -184,7 +199,7 @@ pub fn read_and_transform<R: Read, F: FnMut(OriginalQuery, Query)>(
 
     for transformer in options.transformers {
         let _ = transformer_by_db_and_table_and_column_name.insert(
-            transformer.database_and_table_and_column_name(),
+            transformer.database_and_quoted_table_and_column_name(),
             transformer,
         );
     }
@@ -281,6 +296,7 @@ fn transform_columns(
     // R Paren      -> position X?
     let column_names = get_column_names_from_insert_into_query(&tokens);
     let column_values = get_column_values_from_insert_into_query(&tokens);
+    assert_eq!(column_names.len(), column_values.len(), "Column names do not match values: got {} names and {} values", column_names.len(), column_values.len());
 
     let mut original_columns = vec![];
     let mut columns = vec![];
@@ -493,6 +509,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
 
         assert!(p.read(source_options, |original_query, query| {}).is_ok());
@@ -504,6 +521,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
 
         assert!(p.read(source_options, |original_query, query| {}).is_err());
@@ -518,6 +536,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
 
         let _ = p.read(source_options, |original_query, query| {
@@ -643,6 +662,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &vec![],
             database_subset: &None,
+            only_tables: &vec![],
         };
 
         let _ = p.read(source_options, |original_query, query| {
@@ -683,6 +703,7 @@ mod tests {
             transformers: &transformers,
             skip_config: &skip_config,
             database_subset: &None,
+            only_tables: &vec![],
         };
 
         let _ = p.read(source_options, |_original_query, query| {
@@ -733,6 +754,7 @@ mod tests {
                 ),
                 passthrough_tables: None,
             }),
+            only_tables: &vec![],
         };
 
         let mut rows_percent_50 = vec![];
@@ -769,6 +791,7 @@ mod tests {
                 ),
                 passthrough_tables: None,
             }),
+            only_tables: &vec![],
         };
 
         let mut rows_percent_30 = vec![];
